#!/usr/bin/env bash
#
# This file is part of the KubeVirt project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Copyright 2017-2019 Red Hat, Inc.

set -ex

source ./cluster/cluster.sh
export OPERATOR_NAMESPACE=cluster-network-addons
export KUBECONFIG=$(cluster::kubeconfig)
export KUBECTL=$CLUSTER_PATH/cluster-up/kubectl.sh

${GINKGO} ./${TEST_SUITE} ../ -- ${TEST_ARGS}
